﻿-- PROCESO DE CREACIÓN DE LAS TABLAS DE RIESGO PARA CONSTRUCCIONES RÚSTICAS

/*EN PRIMER LUGAR SE CREA UNA TABLA DE BIENES TOTALES CON EL CÓDIGO DE USO Y LAS CONSTRUCCIONES DE CADA ENTIDAD.
CABE COMENTAR QUE EL RESULTADO QUE SE OBTENDRÁ DUPLICARÁ EN OCASIONES LOS REGISTROS DEBIDO A QUE UNA MISMA CONSTRUCCIÓN
PUEDE TENER DIVERSOS NIVELES -I, II ETC. ASÍ COMO USOS. PARA ELLO:


*/


CREATE TABLE riesgo.constru_r_distinct as (SELECT  distinct on (a.ninterno)ninterno, row_number() OVER (ORDER BY a.parcat) 
AS row_number, a.parcat, a.constru, a.geom, b.cod_uso FROM lora.constru_r a, lora.bienin_cat b WHERE ((a.parcat)::text = b.parcat) ORDER BY a.ninterno);



-- EN SEGUNDO LUGAR ESTOS OBTENEMOS UNA TABLA DE LOS BIENES AFECTADOS POR LAS INUNDACIONES, YA QUE SÓLO ESTOS BIENES SON LOS QUE NOS INTERESAN. PARA ELLO: 

CREATE TABLE riesgo.construcciones_r_afectadas_inunda_500 as (
select row_number () over (order by a.parcat) as gid, a.ninterno, a.parcat, a.constru, a.geom, a.cod_uso 
from riesgo.constru_r_distinct a, lora.zoninun_500 b where st_intersects(a.geom, b.geom));

CREATE TABLE riesgo.construcciones_r_afectadas_inunda_100 as (
select row_number () over (order by a.parcat) as gid, a.ninterno, a.parcat, a.constru, a.geom, a.cod_uso 
from riesgo.constru_r_distinct a, lora.zoninun_100 b where st_intersects(a.geom, b.geom));


CREATE TABLE riesgo.construcciones_r_afectadas_inunda_50 as (
select row_number () over (order by a.parcat) as gid, a.ninterno, a.parcat, a.constru, a.geom, a.cod_uso 
from riesgo.constru_r_distinct a, lora.zoninun_50 b where st_intersects(a.geom, b.geom));


CREATE TABLE riesgo.construcciones_r_afectadas_inunda_10 as (
select row_number () over (order by a.parcat) as gid, a.ninterno, a.parcat, a.constru, a.geom, a.cod_uso 
from riesgo.constru_r_distinct a, lora.zoninun_10 b where st_intersects(a.geom, b.geom));



-- EN TERCER LUGAR SE PROCEDE A REALIZAR EL ESTUDIO DE VULNERABILIDAD ASIGNANDO VALORES A LOS USOS Y CONSTRUCCIONES. PARA ELLO: 


create table riesgo.riesgo_construcciones_r_inunda_500_tabla as (
WITH  vulnerabilidad as (
SELECT parcat, CASE
when cod_uso='V' and constru NOT LIKE '-%' THEN 3
when cod_uso='V' and constru LIKE '-%' THEN 4
WHEN cod_uso='Y' then 4
when cod_uso IN ('R', 'C', 'E', 'G') THEN 2
else 1
END as vulnerabilidad, geom
from riesgo.construcciones_r_afectadas_inunda_500),
vul_pel as (
SELECT a.parcat, a.vulnerabilidad, CASE
when st_intersects (a.geom, b.geom) then 4
when st_intersects (a.geom, c.geom) and not st_intersects (a.geom, b.geom) then 3
when st_intersects (a.geom, d.geom) and not st_intersects (a.geom, c.geom) then 2
when st_intersects (a.geom, e.geom) and not st_intersects (a.geom, d.geom) then 1
END as peligrosidad, a.geom
from vulnerabilidad a, lora.zoninun_10 b, lora.zoninun_50
c, lora.zoninun_100 d, lora.zoninun_500 e)
SELECT row_number () OVER (ORDER BY a.parcat) as gid, a.parcat,
a.vulnerabilidad, a.peligrosidad, a.vulnerabilidad*a.peligrosidad as riesgo,
a.geom
from vul_pel a);


create table riesgo.riesgo_construcciones_r_inunda_100_tabla as (
WITH  vulnerabilidad as (
SELECT parcat, CASE
when cod_uso='V' and constru NOT LIKE '-%' THEN 3
when cod_uso='V' and constru LIKE '-%' THEN 4
WHEN cod_uso='Y' then 4
when cod_uso IN ('R', 'C', 'E', 'G') THEN 2
else 1
END as vulnerabilidad, geom
from riesgo.construcciones_r_afectadas_inunda_100),
vul_pel as (
SELECT a.parcat, a.vulnerabilidad, CASE
when st_intersects (a.geom, b.geom) then 4
when st_intersects (a.geom, c.geom) and not st_intersects (a.geom,
b.geom) then 3
when st_intersects (a.geom, d.geom) and not st_intersects (a.geom, c.geom) then 2
when st_intersects (a.geom, e.geom) and not st_intersects (a.geom, d.geom) then 1
END as peligrosidad, a.geom
from vulnerabilidad a, lora.zoninun_10 b, lora.zoninun_50
c, lora.zoninun_100 d, lora.zoninun_500 e)
SELECT row_number () OVER (ORDER BY a.parcat) as gid, a.parcat,
a.vulnerabilidad, a.peligrosidad, a.vulnerabilidad*a.peligrosidad as riesgo,
a.geom
from vul_pel a);



create table riesgo.riesgo_construcciones_r_inunda_50_tabla as (
WITH  vulnerabilidad as (
SELECT parcat, CASE
when cod_uso='V' and constru NOT LIKE '-%' THEN 3
when cod_uso='V' and constru LIKE '-%' THEN 4
WHEN cod_uso='Y' then 4
when cod_uso IN ('R', 'C', 'E', 'G') THEN 2
else 1
END as vulnerabilidad, geom
from riesgo.construcciones_r_afectadas_inunda_50),
vul_pel as (
SELECT a.parcat, a.vulnerabilidad, CASE
when st_intersects (a.geom, b.geom) then 4
when st_intersects (a.geom, c.geom) and not st_intersects (a.geom,
b.geom) then 3
when st_intersects (a.geom, d.geom) and not st_intersects (a.geom, c.geom) then 2
when st_intersects (a.geom, e.geom) and not st_intersects (a.geom, d.geom) then 1
END as peligrosidad, a.geom
from vulnerabilidad a, lora.zoninun_10 b, lora.zoninun_50
c, lora.zoninun_100 d, lora.zoninun_500 e)
SELECT row_number () OVER (ORDER BY a.parcat) as gid, a.parcat,
a.vulnerabilidad, a.peligrosidad, a.vulnerabilidad*a.peligrosidad as riesgo,
a.geom
from vul_pel a);


create table riesgo.riesgo_construcciones_r_inunda_10_tabla as (
WITH  vulnerabilidad as (
SELECT parcat, CASE
when cod_uso='V' and constru NOT LIKE '-%' THEN 3
when cod_uso='V' and constru LIKE '-%' THEN 4
WHEN cod_uso='Y' then 4
when cod_uso IN ('R', 'C', 'E', 'G') THEN 2
else 1
END as vulnerabilidad, geom
from riesgo.construcciones_r_afectadas_inunda_10),
vul_pel as (
SELECT a.parcat, a.vulnerabilidad, CASE
when st_intersects (a.geom, b.geom) then 4
when st_intersects (a.geom, c.geom) and not st_intersects (a.geom,
b.geom) then 3
when st_intersects (a.geom, d.geom) and not st_intersects (a.geom, c.geom) then 2
when st_intersects (a.geom, e.geom) and not st_intersects (a.geom, d.geom) then 1
END as peligrosidad, a.geom
from vulnerabilidad a, lora.zoninun_10 b, lora.zoninun_50
c, lora.zoninun_100 d, lora.zoninun_500 e)
SELECT row_number () OVER (ORDER BY a.parcat) as gid, a.parcat,
a.vulnerabilidad, a.peligrosidad, a.vulnerabilidad*a.peligrosidad as riesgo,
a.geom
from vul_pel a);


